@@ -17,7 +17,7 @@ from astropy.coordinates import (EarthLocation, Latitude, Longitude, SkyCoord,
 from astropy.tests.helper import assert_quantity_allclose
 
 # Package
-from ..observer import Observer, MAGIC_TIME
+from ..observer import Observer
 from ..target import FixedTarget
 from ..exceptions import TargetAlwaysUpWarning, TargetNeverUpWarning
 
@@ -270,7 +270,7 @@ def test_parallactic_angle():
 
 
 def print_pyephem_parallactic_angle():
-    lat = 19.826218*u.deg
+    # lat = 19.826218*u.deg
     lon = -155.471999*u.deg
     time = Time('2015-01-01 00:00:00')
     LST = time.sidereal_time('mean', longitude=lon)
@@ -779,7 +779,6 @@ def test_solar_transit_convenience_methods():
     pressure = 0 * u.bar
     location = EarthLocation.from_geodetic(lon, lat, elevation)
     time = Time('2000-01-01 12:00:00')
-    from astropy.coordinates import get_sun
     obs = Observer(location=location, pressure=pressure)
 
     # Compute next/previous noon/midnight using generic calc_transit methods
@@ -1002,7 +1001,7 @@ def test_TargetAlwaysUpWarning(recwarn):
 
     w = recwarn.pop(TargetAlwaysUpWarning)
     assert issubclass(w.category, TargetAlwaysUpWarning)
-    assert no_time == MAGIC_TIME
+    assert no_time.mask
 
 
 def test_TargetNeverUpWarning(recwarn):
@@ -1018,7 +1017,7 @@ def test_TargetNeverUpWarning(recwarn):
 
     w = recwarn.pop(TargetNeverUpWarning)
     assert issubclass(w.category, TargetNeverUpWarning)
-    assert no_time == MAGIC_TIME
+    assert no_time.mask
 
 
 def test_mixed_rise_and_dont_rise():
@@ -1034,9 +1033,9 @@ def test_mixed_rise_and_dont_rise():
     with pytest.warns(TargetAlwaysUpWarning) as recwarn:
         rise_times = obs.target_rise_time(time, targets, which='next')
 
-    assert rise_times[1] == MAGIC_TIME
+    assert rise_times.mask[1]
 
-    targets_that_rise = np.array(targets)[rise_times != MAGIC_TIME]
+    targets_that_rise = np.array(targets)[~rise_times.mask]
     assert np.all([vega, sirius] == targets_that_rise)
 
     w = recwarn.pop(TargetAlwaysUpWarning)
@@ -1234,7 +1233,7 @@ def test_tonight():
 
     post_civil_sunset = Time('2016-08-08 05:00:00')
     during_twilight = obs.tonight(time=post_civil_sunset, horizon=horizon)
-    during_twilight_wo_horizon = obs.tonight(time=post_civil_sunset)
+    during_twilight_wo_horizon = obs.tonight(time=post_civil_sunset)  # noqa
 
     # Get correct astro sunset if checking after civil sunset
     assert (abs(astro_sunset.datetime - during_twilight[0].datetime) <
@@ -1279,7 +1278,7 @@ def test_moon_rise_set():
     lat = '42:00:00'
     lon = '-70:00:00'
     elevation = 0.0 * u.m
-    pressure = 0 * u.bar
+    # pressure = 0 * u.bar
     location = EarthLocation.from_geodetic(lon, lat, elevation)
 
     obs = Observer(location=location)
@@ -1298,3 +1297,32 @@ def test_moon_rise_set():
             datetime.timedelta(minutes=threshold_minutes))
     assert (abs(pyephem_prev_set - astroplan_prev_set.datetime) <
             datetime.timedelta(minutes=threshold_minutes))
+
+
+mmto_sunsets = [
+    Time('2019-01-01 00:31'),
+    Time('2019-02-01 00:58'),
+    Time('2019-03-01 01:21'),
+    Time('2019-04-01 01:43'),
+    Time('2019-05-01 02:03'),
+    Time('2019-06-01 02:24'),
+]
+
+
+@pytest.mark.parametrize('mmto_sunset', mmto_sunsets)
+def test_sun_set_vs_mmto_almanac(mmto_sunset):
+    """
+    Validates issue: https://github.com/astropy/astroplan/issues/409
+
+    MMTO times to the nearest minute from the MMTO Almanac:
+    http://www.mmto.org/sites/default/files/almanac_2019.pdf
+    """
+    loc = EarthLocation.from_geodetic(-110.8850*u.deg, 31.6883 * u.deg,
+                                      2608 * u.m)
+    mmt = Observer(location=loc, pressure=0*u.bar)
+
+    # Compute equivalent time with astroplan
+    astroplan_sunset = mmt.sun_set_time(mmto_sunset - 10*u.min,
+                                        horizon=-0.8333*u.deg, which='next')
+
+    assert abs(mmto_sunset - astroplan_sunset) < 1 * u.min
